[gs-cvs] rev 7472 - trunk/gs/src

ghostgum at ghostscript.com ghostgum at ghostscript.com
Fri Dec 8 13:47:02 PST 2006


Author: ghostgum
Date: 2006-12-08 13:47:01 -0800 (Fri, 08 Dec 2006)
New Revision: 7472

Modified:
   trunk/gs/src/dwreg.c
   trunk/gs/src/dwsetup.cpp
   trunk/gs/src/dwsetup.def
   trunk/gs/src/dwsetup.rc
   trunk/gs/src/dwuninst.cpp
   trunk/gs/src/dwuninst.def
   trunk/gs/src/gp_wgetv.c
   trunk/gs/src/winint.mak
Log:
Change MS-Windows installer to identify itself as GPL not AFPL Ghostscript.


Modified: trunk/gs/src/dwreg.c
===================================================================
--- trunk/gs/src/dwreg.c	2006-12-08 21:45:06 UTC (rev 7471)
+++ trunk/gs/src/dwreg.c	2006-12-08 21:47:01 UTC (rev 7472)
@@ -21,8 +21,8 @@
 #include "gscdefs.h"		/* for gs_productfamily and gs_revision */
 
 /* We store registry named values under the key 
- * "Software\\AFPL Ghostscript"
- * where "AFPL Ghostscript" is actually gs_productfamily.
+ * "Software\\GPL Ghostscript"
+ * where "GPL Ghostscript" is actually gs_productfamily.
  * Either HKEY_LOCAL_MACHINE or HKEY_CURRENT_USER will be used.
  */
 int

Modified: trunk/gs/src/dwsetup.cpp
===================================================================
--- trunk/gs/src/dwsetup.def	2006-12-08 21:45:06 UTC (rev 7471)
+++ trunk/gs/src/dwsetup.def	2006-12-08 21:47:01 UTC (rev 7472)
@@ -1,4 +1,4 @@
-;	'AFPL Ghostscript Setup'
+;	'Ghostscript Setup'
 NAME		SETUPGS
 HEAPSIZE	4096
 STACKSIZE	32768

Modified: trunk/gs/src/dwsetup.rc
===================================================================
--- trunk/gs/src/dwsetup.rc	2006-12-08 21:45:06 UTC (rev 7471)
+++ trunk/gs/src/dwsetup.rc	2006-12-08 21:47:01 UTC (rev 7472)
@@ -28,7 +28,7 @@
 
 IDD_MAIN DIALOG 32, 32, 300, 200
 STYLE DS_MODALFRAME | DS_3DLOOK | WS_POPUP /* | WS_VISIBLE */ | WS_CAPTION | WS_SYSMENU 
-CAPTION "AFPL Ghostscript Setup"
+CAPTION "GPL Ghostscript Setup"
 FONT 8, "MS Sans Serif"
 BEGIN
     DEFPUSHBUTTON   "Install",IDC_INSTALL,240,178,50,14
@@ -61,7 +61,7 @@
 
 IDD_TEXTWIN DIALOG DISCARDABLE  0, 0, 318, 169
 STYLE DS_MODALFRAME | DS_3DLOOK | WS_POPUP | WS_VISIBLE | WS_CAPTION | WS_SYSMENU
-CAPTION "AFPL Ghostscript setup log"
+CAPTION "GPL Ghostscript setup log"
 FONT 8, "MS Sans Serif"
 BEGIN
     PUSHBUTTON      "Cancel",IDCANCEL,261,148,50,14
@@ -136,7 +136,7 @@
 
 STRINGTABLE DISCARDABLE 
 BEGIN
-    IDS_APPNAME             "AFPL Ghostscript Setup"
+    IDS_APPNAME             "GPL Ghostscript Setup"
     IDS_TARGET_DIR          "gs"
     IDS_TARGET_GROUP        "Ghostscript"
 END

Modified: trunk/gs/src/dwuninst.cpp
===================================================================
--- trunk/gs/src/dwuninst.cpp	2006-12-08 21:45:06 UTC (rev 7471)
+++ trunk/gs/src/dwuninst.cpp	2006-12-08 21:47:01 UTC (rev 7472)
@@ -789,7 +789,7 @@
 	}
 	if (strlen(szLogFile) == 0) {
 		MessageBox(HWND_DESKTOP, "Usage: uninstgs logfile.txt", 
-			"AFPL Ghostscript Uninstall", MB_OK);
+			"GPL Ghostscript Uninstall", MB_OK);
 		return FALSE;
 	}
 	

Modified: trunk/gs/src/dwuninst.def
===================================================================
--- trunk/gs/src/dwuninst.def	2006-12-08 21:45:06 UTC (rev 7471)
+++ trunk/gs/src/dwuninst.def	2006-12-08 21:47:01 UTC (rev 7472)
@@ -1,4 +1,4 @@
-;	'AFPL Ghostscript uninstall'
+;	'Ghostscript uninstall'
 NAME		UNINSTGS
 HEAPSIZE	4096
 STACKSIZE	32768

Modified: trunk/gs/src/gp_wgetv.c
===================================================================
--- trunk/gs/src/gp_wgetv.c	2006-12-08 21:45:06 UTC (rev 7471)
+++ trunk/gs/src/gp_wgetv.c	2006-12-08 21:47:01 UTC (rev 7472)
@@ -51,10 +51,10 @@
     {
 	/* If using Win32, look in the registry for a value with
 	 * the given name.  The registry value will be under the key
-	 * HKEY_CURRENT_USER\Software\AFPL Ghostscript\N.NN
+	 * HKEY_CURRENT_USER\Software\GPL Ghostscript\N.NN
 	 * or if that fails under the key
-	 * HKEY_LOCAL_MACHINE\Software\AFPL Ghostscript\N.NN
-	 * where "AFPL Ghostscript" is actually gs_productfamily
+	 * HKEY_LOCAL_MACHINE\Software\GPL Ghostscript\N.NN
+	 * where "GPL Ghostscript" is actually gs_productfamily
 	 * and N.NN is obtained from gs_revision.
 	 */
 	DWORD version = GetVersion();

Modified: trunk/gs/src/winint.mak
===================================================================
--- trunk/gs/src/winint.mak	2006-12-08 21:45:06 UTC (rev 7471)
+++ trunk/gs/src/winint.mak	2006-12-08 21:47:01 UTC (rev 7472)
@@ -253,8 +253,8 @@
 	echo $(ZIPPROGFILE7) >> $(ZIPTEMPFILE)
 	echo $(ZIPPROGFILE8) >> $(ZIPTEMPFILE)
 	echo $(ZIPPROGFILE9) >> $(ZIPTEMPFILE)
-	$(SETUP_XE_NAME) -title "AFPL Ghostscript $(GS_DOT_VERSION)" -dir "gs$(GS_DOT_VERSION)" -list "$(FILELIST_TXT)" @$(ZIPTEMPFILE)
-	$(SETUP_XE_NAME) -title "AFPL Ghostscript Fonts" -dir "fonts" -list "$(FONTLIST_TXT)" $(ZIPFONTFILES)
+	$(SETUP_XE_NAME) -title "GPL Ghostscript $(GS_DOT_VERSION)" -dir "gs$(GS_DOT_VERSION)" -list "$(FILELIST_TXT)" @$(ZIPTEMPFILE)
+	$(SETUP_XE_NAME) -title "GPL Ghostscript Fonts" -dir "fonts" -list "$(FONTLIST_TXT)" $(ZIPFONTFILES)
 	-del $(ZIPTARGET).zip
 	$(ZIP_XE) -9 $(ZIPTARGET).zip $(SETUP_XE_NAME) $(UNINSTALL_XE_NAME) $(FILELIST_TXT) $(FONTLIST_TXT)
 	$(ZIP_XE) -9 -r $(ZIPTARGET).zip $(ZIPFONTDIR)
@@ -287,16 +287,16 @@
 # as used by Windows XP.
 archive: zip $(PSOBJ)gswin16.ico $(ECHOGS_XE)
 	$(ECHOGS_XE) -w $(ZIP_RSP) -q "-win32 -setup"
-	$(ECHOGS_XE) -a $(ZIP_RSP) -q -st -x 22 AFPL Ghostscript $(GS_DOT_VERSION) for Win32 -x 22
+	$(ECHOGS_XE) -a $(ZIP_RSP) -q -st -x 22 GPL Ghostscript $(GS_DOT_VERSION) for Win32 -x 22
 	$(ECHOGS_XE) -a $(ZIP_RSP) -q -i -s $(PSOBJ)gswin16.ico
 	$(ECHOGS_XE) -a $(ZIP_RSP) -q -a -s $(PSOBJ)about.txt
 	$(ECHOGS_XE) -a $(ZIP_RSP) -q -t -s $(PSOBJ)dialog.txt
 	$(ECHOGS_XE) -a $(ZIP_RSP) -q -c -s $(SETUP_XE_NAME)
-	$(ECHOGS_XE) -w $(PSOBJ)about.txt "AFPL Ghostscript is Copyright " -x A9 " 2005 artofcode LLC."
+	$(ECHOGS_XE) -w $(PSOBJ)about.txt "GPL Ghostscript is Copyright " -x A9 " 2006 artofcode LLC."
 	$(ECHOGS_XE) -a $(PSOBJ)about.txt See license in gs$(GS_DOT_VERSION)\doc\Public.htm.
 	$(ECHOGS_XE) -a $(PSOBJ)about.txt See gs$(GS_DOT_VERSION)\doc\Commprod.htm regarding commercial distribution.
-	$(ECHOGS_XE) -w $(PSOBJ)dialog.txt This installs AFPL Ghostscript $(GS_DOT_VERSION).
-	$(ECHOGS_XE) -a $(PSOBJ)dialog.txt AFPL Ghostscript displays, prints and converts PostScript and PDF files.
+	$(ECHOGS_XE) -w $(PSOBJ)dialog.txt This installs GPL Ghostscript $(GS_DOT_VERSION).
+	$(ECHOGS_XE) -a $(PSOBJ)dialog.txt GPL Ghostscript displays, prints and converts PostScript and PDF files.
 	$(WINZIPSE_XE) ..\$(ZIPTARGET) @$(PSOBJ)setupgs.rsp
 # Don't delete temporary files, because make continues
 # before these files are used.



More information about the gs-cvs mailing list
--- trunk/gs/src/dwsetup.cpp	2006-12-08 21:45:06 UTC (rev 7471)
+++ trunk/gs/src/dwsetup.cpp	2006-12-08 21:47:01 UTC (rev 7472)
@@ -14,7 +14,7 @@
 // $Id$
 //
 //
 // This is the setup program for Win32 AFPL Ghostscript
 //
 // The starting point is a self extracting zip archive
 // with the following contents:
@@ -34,12 +34,12 @@
 // uninstall log files are to be placed.  
 // Subsequent lines contain files to be copied (but not directories).
 // For example, filelist.txt might contain:
-//   AFPL Ghostscript 6.50
-//   gs6.50
-//   gs6.50\bin\gsdll32.dll
-//   gs6.50\lib\gs_init.ps
+//   GPL Ghostscript 8.55
+//   gs8.55
+//   gs8.55\bin\gsdll32.dll
+//   gs8.55\lib\gs_init.ps
 // The file fontlist.txt might contain:
 //   AFPL Ghostscript Fonts
 //   fonts
 //   fonts\n019003l.pfb
 //   fonts\n019023l.pfb
@@ -714,7 +714,7 @@
 BOOL
 install_prog()
 {
-	char *regkey1 = "AFPL Ghostscript";
+	char *regkey1 = "GPL Ghostscript";
 	char regkey2[16];
 	char szDLL[MAXSTR];
 	char szLIB[MAXSTR+MAXSTR];
@@ -1182,7 +1182,7 @@
 		    if ((title == NULL) || (strlen(title) == 0) ||
 			(dir == NULL) || (strlen(dir) == 0) ||
 			(list == NULL) || (strlen(list) == 0)) {
-			message_box("Usage: setupgs -title \042AFPL Ghostscript #.##\042 -dir \042gs#.##\042 -list \042filelist.txt\042 spec1 spec2 specn\n");
+			message_box("Usage: setupgs -title \042GPL Ghostscript #.##\042 -dir \042gs#.##\042 -list \042filelist.txt\042 spec1 spec2 specn\n");
 			return FALSE;
 		    }
 		    if (fList == (FILE *)NULL) {
@@ -14,7 +14,7 @@
 //
 //
-// This is the setup program for Win32 AFPL Ghostscript
+// This is the setup program for Win32 GPL Ghostscript
 //
 // The starting point is a self extracting zip archive
@@ -34,12 +34,12 @@
 // The file fontlist.txt might contain:
-//   AFPL Ghostscript Fonts
+//   GPL Ghostscript Fonts
 //   fonts
 //   fonts\n019003l.pfb

Modified: trunk/gs/src/dwsetup.def
===================================================================